ClassificationMetricResults
===========================

.. currentmodule:: pykeen.evaluation

.. autoclass:: ClassificationMetricResults
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ClassificationMetricResults.metrics

   .. rubric:: Methods Summary

   .. autosummary::

      ~ClassificationMetricResults.from_scores
      ~ClassificationMetricResults.get_metric

   .. rubric:: Attributes Documentation

   .. autoattribute:: metrics

   .. rubric:: Methods Documentation

   .. automethod:: from_scores
   .. automethod:: get_metric
